Search Header Logo

HPC-Quiz-FT IV

Authored by Sorna K

Computers

University

Used 1+ times

HPC-Quiz-FT IV
AI

AI Actions

Add similar questions

Adjust reading levels

Convert to real-world scenario

Translate activity

More...

    Content View

    Student View

25 questions

Show all answers

1.

MULTIPLE CHOICE QUESTION

10 sec • 1 pt

What is the correct way to free allocated GPU memory?

free(ptr);

cudaFree(ptr);

gpuFree(ptr);

cudaDealloc(ptr);

2.

MULTIPLE CHOICE QUESTION

10 sec • 1 pt

Which function is used to copy data from the CPU to the GPU?

cudaMemcpy(dest, src, size, cudaHostToDevice);

cudaCopy(dest, src, size, cudaMemcpyHostToDevice);

cudaMemcpy(dest, src, size, cudaMemcpyHostToDevice);

memcpy(dest, src, size);

3.

MULTIPLE CHOICE QUESTION

10 sec • 1 pt

How do you allocate memory on the GPU?

malloc(size);

cudaMalloc(&ptr, size);

gpuAlloc(&ptr, size);

cudaAlloc(&ptr, size);

4.

MULTIPLE CHOICE QUESTION

10 sec • 1 pt

What does the threadIdx.x variable represent?

The index of the current thread within a block

The index of the current block within the grid

The total number of threads in a block

The total number of blocks in the grid

5.

MULTIPLE CHOICE QUESTION

10 sec • 1 pt

Which keyword is used to define a function that runs on the GPU but is called from the CPU?

__device__

__global__

__host__

__gpu__

6.

MULTIPLE CHOICE QUESTION

10 sec • 1 pt

How do you declare a CUDA kernel function?

void kernel<<<...>>>();

__global__ void kernel() {}

__kernel void kernel() {}

gpu_function void kernel() {}

7.

MULTIPLE CHOICE QUESTION

10 sec • 1 pt

How do you launch a CUDA kernel with 256 threads per block?

kernel();

kernel<<<1, 256>>>();

kernel<<<256, 1>>>();

kernel<<<256>>>();

Access all questions and much more by creating a free account

Create resources

Host any resource

Get auto-graded reports

Google

Continue with Google

Email

Continue with Email

Microsoft

Continue with Microsoft

or continue with

Facebook

Facebook

Apple

Apple

Others

Others

Already have an account?